@@ -1,7 +1,7 @@
 ;;; add-log.el --- change log maintenance commands for Emacs
 
 ;; Copyright (C) 1985, 1986, 1988, 1993, 1994, 1997, 1998, 2000, 2001,
-;;   2002, 2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
+;;   2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Maintainer: FSF
 ;; Keywords: tools
@@ -10,7 +10,7 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
@@ -509,19 +509,19 @@ non-nil, otherwise in local time."
 	 (file-name (expand-file-name (find-change-log file-name buffer-file)))
 	 ;; Set ITEM to the file name to use in the new item.
 	 (item (add-log-file-name buffer-file file-name))
-	 bound
-	 (full-name (or add-log-full-name (user-full-name)))
-	 (mailing-address (or add-log-mailing-address user-mail-address)))
+	 bound full-name mailing-address)
 
     (if whoami
 	(progn
-	  (setq full-name (read-string "Full name: " full-name))
+	  (setq full-name (read-string "Full name: "
+				       (or add-log-full-name (user-full-name))))
 	  ;; Note that some sites have room and phone number fields in
 	  ;; full name which look silly when inserted.  Rather than do
 	  ;; anything about that here, let user give prefix argument so that
 	  ;; s/he can edit the full name field in prompter if s/he wants.
 	  (setq mailing-address
-		(read-string "Mailing address: " mailing-address))))
+		(read-string "Mailing address: "
+			     (or add-log-mailing-address user-mail-address)))))
 
     (unless (equal file-name buffer-file-name)
       (if (or other-window (window-dedicated-p (selected-window)))
@@ -532,6 +532,11 @@ non-nil, otherwise in local time."
     (undo-boundary)
     (goto-char (point-min))
 
+    (or full-name
+	(setq full-name (or add-log-full-name (user-full-name))))
+    (or mailing-address
+	 (setq mailing-address (or add-log-mailing-address user-mail-address)))
+
     ;; If file starts with a copyright and permission notice, skip them.
     ;; Assume they end at first blank line.
     (when (looking-at "Copyright")
@@ -660,7 +665,6 @@ the change log file in another window."
 		   (list current-prefix-arg
 			 (prompt-for-change-log-name))))
   (add-change-log-entry whoami file-name t))
-;;;###autoload (define-key ctl-x-4-map "a" 'add-change-log-entry-other-window)
 
 (defvar change-log-indent-text 0)
 
@@ -794,166 +798,9 @@ Has a preference of looking backwards."
 		   (buffer-substring-no-properties (point)
 						   (progn (forward-sexp 1)
 							  (point)))))
-		((and (memq major-mode add-log-c-like-modes)
-		      (save-excursion
-			(beginning-of-line)
-			;; Use eq instead of = here to avoid
-			;; error when at bob and char-after
-			;; returns nil.
-			(while (eq (char-after (- (point) 2)) ?\\)
-			  (forward-line -1))
-			(looking-at "[ \t]*#[ \t]*define[ \t]")))
-		 ;; Handle a C macro definition.
-		 (beginning-of-line)
-		 (while (eq (char-after (- (point) 2)) ?\\) ;not =; note above
-		   (forward-line -1))
-		 (search-forward "define")
-		 (skip-chars-forward " \t")
-		 (buffer-substring-no-properties (point)
-						 (progn (forward-sexp 1)
-							(point))))
 		((memq major-mode add-log-c-like-modes)
-		 ;; See whether the point is inside a defun.
-		 (let (having-previous-defun
-		       having-next-defun
-		       previous-defun-end
-		       next-defun-beginning)
-		     
-		   (save-excursion
-		     (setq having-previous-defun
-			   (c-beginning-of-defun))
-		     (c-end-of-defun)
-		     ;; `c-end-of-defun' moves point to the line after
-		     ;; the function close, but the position we prefer
-		     ;; here is the position after the final }.
-		     (backward-sexp 1)
-		     (forward-sexp 1)
-                     ;; Skip the semicolon ``;'' for
-		     ;; enum/union/struct/class definition.
-		     (if (= (char-after (point)) ?\;)
-			 (forward-char 1))
-		     (setq previous-defun-end (point)))
-
-		   (save-excursion
-		     (setq having-next-defun
-			   (c-end-of-defun))
-		     (c-beginning-of-defun)
-		     (setq next-defun-beginning (point)))
-
-		   (if (and having-next-defun
-			    (< location next-defun-beginning))
-		       (skip-syntax-forward " "))
-		   (if (and having-previous-defun
-			    (> location previous-defun-end))
-		       (skip-syntax-backward " "))
-		   (unless (or
-			    ;; When there is no previous defun, the
-			    ;; point is not in a defun if it is not at
-			    ;; the beginning of the next defun.
-			    (and (not having-previous-defun)
-				 (not (= (point)
-					 next-defun-beginning)))
-			    ;; When there is no next defun, the point
-			    ;; is not in a defun if it is not at the
-			    ;; end of the previous defun.
-			    (and (not having-next-defun)
-				 (not (= (point)
-					 previous-defun-end)))
-			    ;; If the point is between two defuns, it
-			    ;; is not in a defun.
-			    (and (> (point) previous-defun-end)
-				 (< (point) next-defun-beginning)))
-		     ;; If the point is already at the beginning of a
-		     ;; defun, there is no need to move point again.
-		     (if (not (= (point) next-defun-beginning))
-			 (c-beginning-of-defun))
-		     ;; Is this a DEFUN construct?  And is LOCATION in it?
-		     (if (and (looking-at "DEFUN\\b")
-			      (>= location (point)))
-                         ;; DEFUN ("file-name-directory", Ffile_name_directory, Sfile_name_directory, ...) ==> Ffile_name_directory
-                         ;; DEFUN(POSIX::STREAM-LOCK, stream lockp &key BLOCK SHARED START LENGTH) ==> POSIX::STREAM-LOCK
-			 (progn
-			   (down-list 1)
-			   (when (= (char-after (point)) ?\")
-                             (forward-sexp 1)
-                             (search-forward ","))
-                           (skip-syntax-forward " ")
-			   (buffer-substring-no-properties
-			    (point)
-			    (progn (search-forward ",")
-                                   (forward-char -1)
-                                   (skip-syntax-backward " ")
-				   (point))))
-		       (if (looking-at "^[+-]")
-			   ;; Objective-C
-			   (change-log-get-method-definition)
-			 ;; Ordinary C function syntax.
-			 (let ((beg (point)))
-			   (if (and
-				;; Protect against "Unbalanced parens" error.
-				(condition-case nil
-				    (progn
-				      (down-list 1) ; into arglist
-				      (backward-up-list 1)
-				      (skip-chars-backward " \t")
-				      t)
-				  (error nil))
-				;; Verify initial pos was after
-				;; real start of function.
-				(save-excursion
-				  (goto-char beg)
-				  ;; For this purpose, include the line
-				  ;; that has the decl keywords.  This
-				  ;; may also include some of the
-				  ;; comments before the function.
-				  (while (and (not (bobp))
-					      (save-excursion
-						(forward-line -1)
-						(looking-at "[^\n\f]")))
-				    (forward-line -1))
-				  (>= location (point)))
-				;; Consistency check: going down and up
-				;; shouldn't take us back before BEG.
-				(> (point) beg))
-			       (let (end middle)
-				 ;; Don't include any final whitespace
-				 ;; in the name we use.
-				 (skip-chars-backward " \t\n")
-				 (setq end (point))
-				 (backward-sexp 1)
-				 ;; Now find the right beginning of the name.
-				 ;; Include certain keywords if they
-				 ;; precede the name.
-				 (setq middle (point))
-				 ;; We tried calling `forward-sexp' in a loop
-				 ;; but it causes inconsistency for C names.
-				 (forward-sexp -1)
-				 ;; Is this C++ method?
-				 (when (and (< 2 middle)
-					    (string= (buffer-substring (- middle 2)
-								       middle)
-						     "::"))
-				   ;; Include "classname::".
-				   (setq middle (point)))
-				 ;; Ignore these subparts of a class decl
-				 ;; and move back to the class name itself.
-				 (while (looking-at "public \\|private ")
-				   (skip-chars-backward " \t:")
-				   (setq end (point))
-				   (backward-sexp 1)
-				   (setq middle (point))
-				   (forward-word -1))
-				 (and (bolp)
-				      (looking-at
-				       "enum \\|struct \\|union \\|class ")
-				      (setq middle (point)))
-				 (goto-char end)
-				 (when (eq (preceding-char) ?=)
-				   (forward-char -1)
-				   (skip-chars-backward " \t")
-				   (setq end (point)))
-				 (buffer-substring-no-properties
-				  middle end)))))))))
+		 (or (c-cpp-define-name)
+		     (c-defun-name)))
 		((memq major-mode add-log-tex-like-modes)
 		 (if (re-search-backward
 		      "\\\\\\(sub\\)*\\(section\\|paragraph\\|chapter\\)"
@@ -1099,29 +946,6 @@ old-style time formats for entries are supported."
 	      (goto-char (point-max)))
 	    (insert-buffer-substring other-buf start)))))))
 
-;;;###autoload
-(defun change-log-redate ()
-  "Fix any old-style date entries in the current log file to default format."
-  (interactive)
-  (require 'timezone)
-  (save-excursion
-    (goto-char (point-min))
-    (while (re-search-forward "^\\sw.........[0-9:+ ]*" nil t)
-      (unless (= 12 (- (match-end 0) (match-beginning 0)))
-	(let* ((date (save-match-data
-		       (timezone-fix-time (match-string 0) nil nil)))
-	       (zone (if (consp (aref date 6))
-			 (nth 1 (aref date 6)))))
-	  (replace-match (format-time-string
-			  "%Y-%m-%d  "
-			  (encode-time (aref date 5)
-				       (aref date 4)
-				       (aref date 3)
-				       (aref date 2)
-				       (aref date 1)
-				       (aref date 0)
-				       zone))))))))
-
 (provide 'add-log)
 
 ;; arch-tag: 81eee6fc-088f-4372-a37f-80ad9620e762
