@@ -1,16 +1,18 @@
 ;;; autoinsert.el --- automatic mode-dependent insertion of text into new files
 
-;; Copyright (C) 1985, 1986, 1987, 1994, 1995 Free Software Foundation, Inc.
+;; Copyright (C) 1985, 1986, 1987, 1994, 1995, 1998, 2000, 2001, 2002,
+;;   2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Charlie Martin <crm@cs.duke.edu>
-;; Adapted-By: Daniel.Pfeiffer@Informatik.START.dbp.de, fax (+49 69) 7588-2389
+;; Adapted-By: Daniel Pfeiffer <occitan@esperanto.org>
+;; Keywords: convenience
 ;; Maintainer: FSF
 
 ;; This file is part of GNU Emacs.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
@@ -20,8 +22,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -31,44 +33,65 @@
 ;;  default text much as the mode is automatically set using
 ;;  auto-mode-alist.
 ;;
-;;  To use: 
-;;     (add-hook 'find-file-hooks 'auto-insert)
+;;  To use:
+;;     (add-hook 'find-file-hook 'auto-insert)
 ;;     setq auto-insert-directory to an appropriate slash-terminated value
 ;;
+;;  You can also customize the variable `auto-insert-mode' to load the
+;;  package.  Alternatively, add the following to your .emacs file:
+;;  (auto-insert-mode 1)
+;;
 ;;  Author:  Charlie Martin
 ;;           Department of Computer Science and
 ;;           National Biomedical Simulation Resource
 ;;           Box 3709
 ;;           Duke University Medical Center
 ;;           Durham, NC 27710
-;;	      (crm@cs.duke.edu,mcnc!duke!crm) 
+;;	      (crm@cs.duke.edu,mcnc!duke!crm)
 
 ;;; Code:
 
-(defvar auto-insert 'not-modified
-  "*Controls automatic insertion into newly found empty files:
+(defgroup auto-insert nil
+  "Automatic mode-dependent insertion of text into new files."
+  :prefix "auto-insert-"
+  :group 'files
+  :group 'convenience)
+
+
+(defcustom auto-insert 'not-modified
+  "*Controls automatic insertion into newly found empty files.
+Possible values:
 	nil	do nothing
 	t	insert if possible
 	other	insert if possible, but mark as unmodified.
 Insertion is possible when something appropriate is found in
 `auto-insert-alist'.  When the insertion is marked as unmodified, you can
 save it with  \\[write-file] RET.
-This variable is used when `auto-insert' is called as a function, e.g.
-when you do (add-hook 'find-file-hooks 'auto-insert).
-With \\[auto-insert], this is always treated as if it were `t'.")
+This variable is used when the function `auto-insert' is called, e.g.
+when you do (add-hook 'find-file-hook 'auto-insert).
+With \\[auto-insert], this is always treated as if it were t."
+  :type '(choice (const :tag "Insert if possible" t)
+                 (const :tag "Do nothing" nil)
+                 (other :tag "insert if possible, mark as unmodified."
+                        not-modified))
+  :group 'auto-insert)
 
+(defcustom auto-insert-query 'function
+  "*Non-nil means ask user before auto-inserting.
+When this is `function', only ask when called non-interactively."
+  :type '(choice (const :tag "Don't ask" nil)
+                 (const :tag "Ask if called non-interactively" function)
+                 (other :tag "Ask" t))
+  :group 'auto-insert)
 
-(defvar auto-insert-query 'function
-  "*If non-`nil', ask user before auto-inserting.
-When this is `function', only ask when called non-interactively.")
-
-
-(defvar auto-insert-prompt "Perform %s auto-insertion? "
+(defcustom auto-insert-prompt "Perform %s auto-insertion? "
   "*Prompt to use when querying whether to auto-insert.
-If this contains a %s, that will be replaced by the matching rule.")
+If this contains a %s, that will be replaced by the matching rule."
+  :type 'string
+  :group 'auto-insert)
 
 
-(defvar auto-insert-alist
+(defcustom auto-insert-alist
   '((("\\.\\([Hh]\\|hh\\|hpp\\)\\'" . "C / C++ header")
      (upcase (concat (file-name-nondirectory
 		      (substring buffer-file-name 0 (match-beginning 0)))
@@ -81,22 +104,23 @@ If this contains a %s, that will be replaced by the matching rule.")
     (("\\.\\([Cc]\\|cc\\|cpp\\)\\'" . "C / C++ program")
      nil
      "#include \""
-     ;; nop without latest cc-mode
-     (and (fboundp 'c-companion-file)
-	  ;(file-readable-p (c-companion-file 'name))
-	  (file-name-nondirectory (c-companion-file 'name))) & ?\"
-     | -10)
+     (let ((stem (file-name-sans-extension buffer-file-name)))
+       (cond ((file-exists-p (concat stem ".h"))
+	      (file-name-nondirectory (concat stem ".h")))
+	     ((file-exists-p (concat stem ".hh"))
+	      (file-name-nondirectory (concat stem ".hh")))))
+     & ?\" | -10)
 
-    ("[Mm]akefile\\'" . "makefile.inc")
+    (("[Mm]akefile\\'" . "Makefile") . "makefile.inc")
 
     (html-mode . (lambda () (sgml-tag "html")))
-    
+
     (plain-tex-mode . "tex-insert.tex")
     (bibtex-mode . "tex-insert.tex")
     (latex-mode
      ;; should try to offer completing read for these
      "options, RET: "
-     "\\documentstyle[" str & ?\] | -1
+     "\\documentclass[" str & ?\] | -1
      ?{ (read-string "class: ") "}\n"
      ("package, %s: "
       "\\usepackage[" (read-string "options, RET: ") & ?\] | -1 ?{ str "}\n")
@@ -107,48 +131,75 @@ If this contains a %s, that will be replaced by the matching rule.")
      lambda ()
        (if (eq major-mode default-major-mode)
 	 (sh-mode)))
-    
+
     (ada-mode . ada-header)
 
+    (("\\.[1-9]\\'" . "Man page skeleton")
+     "Short description: "
+     ".\\\" Copyright (C), " (substring (current-time-string) -4) "  "
+     (getenv "ORGANIZATION") | (progn user-full-name)
+     "
+.\\\" You may distribute this file under the terms of the GNU Free
+.\\\" Documentation License.
+.TH " (file-name-sans-extension (file-name-nondirectory (buffer-file-name)))
+     " " (file-name-extension (buffer-file-name))
+     " " (format-time-string "%Y-%m-%d ")
+     "\n.SH NAME\n"
+     (file-name-sans-extension (file-name-nondirectory (buffer-file-name)))
+     " \\- " str
+     "\n.SH SYNOPSIS
+.B " (file-name-sans-extension (file-name-nondirectory (buffer-file-name)))
+     "\n"
+     _
+     "
+.SH DESCRIPTION
+.SH OPTIONS
+.SH FILES
+.SH \"SEE ALSO\"
+.SH BUGS
+.SH AUTHOR
+" (user-full-name)
+     '(if (search-backward "&" (line-beginning-position) t)
+	  (replace-match (capitalize (user-login-name)) t t))
+     '(end-of-line 1) " <" (progn user-mail-address) ">\n")
+
     (("\\.el\\'" . "Emacs Lisp header")
      "Short description: "
      ";;; " (file-name-nondirectory (buffer-file-name)) " --- " str "
 
-;; Copyright (C) " (substring (current-time-string) -4) " by "
- (getenv "ORGANIZATION") | "Free Software Foundation, Inc." "
+;; Copyright (C) " (substring (current-time-string) -4) "  "
+ (getenv "ORGANIZATION") | (progn user-full-name) "
 
 ;; Author: " (user-full-name)
-'(if (search-backward "&" (save-excursion (beginning-of-line 1) (point)) t)
+'(if (search-backward "&" (line-beginning-position) t)
      (replace-match (capitalize (user-login-name)) t t))
-'(end-of-line 1) " <" (user-login-name) ?@ (system-name) ">
+'(end-of-line 1) " <" (progn user-mail-address) ">
 ;; Keywords: "
  '(require 'finder)
  ;;'(setq v1 (apply 'vector (mapcar 'car finder-known-keywords)))
  '(setq v1 (mapcar (lambda (x) (list (symbol-name (car x))))
 		   finder-known-keywords)
-	v2 (mapconcat (lambda (x) (format "%10.0s:  %s" (car x) (cdr x)))
+	v2 (mapconcat (lambda (x) (format "%12s:  %s" (car x) (cdr x)))
 	   finder-known-keywords
 	   "\n"))
  ((let ((minibuffer-help-form v2))
     (completing-read "Keyword, C-h: " v1 nil t))
     str ", ") & -2 "
 
-;; This file is part of GNU Emacs.
-
-;; GNU Emacs is free software; you can redistribute it and/or modify
+;; This file is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
-;; GNU Emacs is distributed in the hope that it will be useful,
+;; This file is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -158,27 +209,36 @@ If this contains a %s, that will be replaced by the matching rule.")
 
 
 
-;;; " (file-name-nondirectory (buffer-file-name)) " ends here"))
+\(provide '"
+       (file-name-sans-extension (file-name-nondirectory (buffer-file-name)))
+       ")
+;;; " (file-name-nondirectory (buffer-file-name)) " ends here\n"))
   "A list specifying text to insert by default into a new file.
 Elements look like (CONDITION . ACTION) or ((CONDITION . DESCRIPTION) . ACTION).
-CONDITION maybe a regexp that must match the new file's name, or it may be
+CONDITION may be a regexp that must match the new file's name, or it may be
 a symbol that must match the major mode for this element to apply.
 Only the first matching element is effective.
 Optional DESCRIPTION is a string for filling `auto-insert-prompt'.
 ACTION may be a skeleton to insert (see `skeleton-insert'), an absolute
 file-name or one relative to `auto-insert-directory' or a function to call.
 ACTION may also be a vector containing several successive single actions as
-described above, e.g. [\"header.insert\" date-and-author-update].")
+described above, e.g. [\"header.insert\" date-and-author-update]."
+  :type 'sexp
+  :group 'auto-insert)
 
 
 ;; Establish a default value for auto-insert-directory
-(defvar auto-insert-directory "~/insert/"
-  "*Directory from which auto-inserted files are taken.")
+(defcustom auto-insert-directory "~/insert/"
+  "*Directory from which auto-inserted files are taken.
+The value must be an absolute directory name;
+thus, on a GNU or Unix system, it must end in a slash."
+  :type 'directory
+  :group 'auto-insert)
 
 
 ;;;###autoload
 (defun auto-insert ()
-  "Insert default contents into a new file if `auto-insert' is non-nil.
+  "Insert default contents into new files if variable `auto-insert' is non-nil.
 Matches the visited file name against the elements of `auto-insert-alist'."
   (interactive)
   (and (not buffer-read-only)
@@ -196,7 +256,8 @@ Matches the visited file name against the elements of `auto-insert-alist'."
 		   cond (car cond)))
 	   (if (if (symbolp cond)
 		   (eq cond major-mode)
-		 (string-match cond buffer-file-name))
+		 (and buffer-file-name
+		      (string-match cond buffer-file-name)))
 	       (setq action (cdr (car alist))
 		     alist nil)
 	     (setq alist (cdr alist))))
@@ -230,15 +291,18 @@ Matches the visited file name against the elements of `auto-insert-alist'."
 		 (vector action))))
 	 (and (buffer-modified-p)
 	      (not (eq this-command 'auto-insert))
-	      (set-buffer-modified-p (eq auto-insert t))))))
+	      (set-buffer-modified-p (eq auto-insert t)))))
+  ;; Return nil so that it could be used in
+  ;; `find-file-not-found-hooks', though that's probably inadvisable.
+  nil)
 
 
 ;;;###autoload
-(defun define-auto-insert (key action &optional after)
+(defun define-auto-insert (condition action &optional after)
   "Associate CONDITION with (additional) ACTION in `auto-insert-alist'.
 Optional AFTER means to insert action after all existing actions for CONDITION,
 or if CONDITION had no actions, after all other CONDITIONs."
-  (let ((elt (assoc key auto-insert-alist)))
+  (let ((elt (assoc condition auto-insert-alist)))
     (if elt
 	(setcdr elt
 		(if (vectorp (cdr elt))
@@ -249,10 +313,24 @@ or if CONDITION had no actions, after all other CONDITIONs."
 		      (vector (cdr elt) action)
 		    (vector action (cdr elt)))))
       (if after
-	  (nconc auto-insert-alist (list (cons key action)))
-	(setq auto-insert-alist (cons (cons key action)
+	  (nconc auto-insert-alist (list (cons condition action)))
+	(setq auto-insert-alist (cons (cons condition action)
 				      auto-insert-alist))))))
 
+;;;###autoload
+(define-minor-mode auto-insert-mode
+  "Toggle Auto-insert mode.
+With prefix ARG, turn Auto-insert mode on if and only if ARG is positive.
+Returns the new status of Auto-insert mode (non-nil means on).
+
+When Auto-insert mode is enabled, when new files are created you can
+insert a template for the file depending on the mode of the buffer."
+  :global t :group 'auto-insert
+  (if auto-insert-mode
+      (add-hook 'find-file-hook 'auto-insert)
+    (remove-hook 'find-file-hook 'auto-insert)))
+
 (provide 'autoinsert)
 
+;; arch-tag: 5b6630ac-c735-43cf-b097-b78c622af909
 ;;; autoinsert.el ends here
