@@ -1,7 +1,7 @@
 /* Implements a lightweight menubar widget.
 Copyright (C) 1992 Lucid, Inc.
 Copyright (C) 1994, 1995, 1997, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007  Free Software Foundation, Inc.
+  2005, 2006, 2007, 2008  Free Software Foundation, Inc.
 
 This file is part of the Lucid Widget Library.
 
