@@ -1,11 +1,12 @@
 /* m- file for Mips machines.
-   Copyright (C) 1987, 1992, 1999 Free Software Foundation, Inc.
+   Copyright (C) 1987, 1992, 1999, 2001, 2002, 2003, 2004,
+                 2005, 2006, 2007, 2008  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
 GNU Emacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU Emacs is distributed in the hope that it will be useful,
@@ -15,20 +16,20 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Emacs; see the file COPYING.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+Boston, MA 02110-1301, USA.  */
 
 
-/* The following line tells the configuration script what sort of 
+/* The following line tells the configuration script what sort of
    operating system this machine is likely to run.
    USUAL-OPSYS="note"
 
 NOTE-START
-Use m-mips4.h for RISCOS version 4; use s-bsd4-3.h with the BSD world.
-Note that the proper m- file for the Decstation is m-pmax.h.
+Use mips4.h for RISCOS version 4; use s-bsd4-3.h with the BSD world.
+Note that the proper m file for the Decstation is pmax.h.
 NOTE-END  */
 
-/* Define WORDS_BIG_ENDIAN iff lowest-numbered byte in a word
+/* Define WORDS_BIG_ENDIAN if lowest-numbered byte in a word
    is the most significant byte.  */
 
 #if ! (defined (__MIPSEL__) || defined (MIPSEL) || defined (_MIPSEL))
@@ -101,19 +102,6 @@ NOTE-END  */
 
 /* #define VIRT_ADDR_VARIES */
 
-/* Define C_ALLOCA if this machine does not support a true alloca
-   and the one written in C should be used instead.
-   Define HAVE_ALLOCA to say that the system provides a properly
-   working alloca function and it should be used.
-   Define neither one if an assembler-language alloca
-   in the file alloca.s should be used.  */
-
-#ifdef __GNUC__
-#define HAVE_ALLOCA
-#else
-#define C_ALLOCA
-#endif
-
 /* Define NO_REMAP if memory segmentation makes it not work well
    to change the boundary between the text section and data section
    when Emacs is dumped.  If you define this, the preloaded Lisp
@@ -124,10 +112,10 @@ NOTE-END  */
 /* This machine requires completely different unexec code
    which lives in a separate file.  Specify the file name.  */
 
-#ifndef __linux__
+#if !defined(__linux__) && !defined(__NetBSD__)
 #undef UNEXEC
 #define UNEXEC unexmips.o
-#endif /* not __linux__ */
+#endif /* not __linux__ && not __NetBSD__ */
 
 /* Describe layout of the address space in an executing process.  */
 
@@ -154,14 +142,6 @@ NOTE-END  */
 #if defined (__NetBSD__) || defined (__OpenBSD__)
 #else  /* bsd with elf */
 #define LINKER /bsd43/bin/ld
-#endif /* bsd with elf */
-#else /* not BSD_SYSTEM */
-
-#if defined(__GNUC__) && defined(_ABIN32)
-#define LIBS_MACHINE
-#else
-#define LIBS_MACHINE -lmld
-#endif
 
 #define LD_SWITCH_MACHINE -D 800000 -g3
 #define START_FILES pre-crt0.o /usr/lib/crt1.o
@@ -171,8 +151,13 @@ NOTE-END  */
 #define C_SWITCH_MACHINE -I/usr/include/bsd
 #define C_DEBUG_SWITCH -O -g3
 
-#if defined(HAVE_X_WINDOWS) && defined(HAVE_X11)
-#define HAVE_VFORK		/* Graciously provided by libX.a */
+#endif /* bsd with elf */
+#else /* not BSD_SYSTEM */
+
+#if defined(__GNUC__) && defined(_ABIN32)
+#define LIBS_MACHINE
+#else
+#define LIBS_MACHINE -lmld
 #endif
 
 #endif /* not BSD_SYSTEM */
@@ -187,11 +172,6 @@ NOTE-END  */
   ((var) =								\
    ((int)(type) << VALBITS)						\
    + (((unsigned) (ptr) << (BITS_PER_INT-VALBITS)) >> (BITS_PER_INT-VALBITS)))
-
-#define XUNMARK(a)							\
-  ((a) =								\
-   (((unsigned)(a) << (BITS_PER_INT-GCTYPEBITS-VALBITS))		\
-    >> (BITS_PER_INT-GCTYPEBITS-VALBITS)))
 
 #if !defined (NEWSOS5) && !defined (__linux__)
 #ifdef USG
@@ -234,3 +214,6 @@ NOTE-END  */
 #endif /* BSD_SYSTEM */
 
 #endif /* not NEWSOS5 && not __linux__ */
+
+/* arch-tag: 8fd020ee-78a7-4d87-96ce-6129f52f7bee
+   (do not change this comment) */
