@@ -1,11 +1,12 @@
 /* machine description file for ns16000.
-   Copyright (C) 1985 Free Software Foundation, Inc.
+   Copyright (C) 1985, 2001, 2002, 2003, 2004, 2005,
+                 2006, 2007, 2008  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
 GNU Emacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU Emacs is distributed in the hope that it will be useful,
@@ -15,11 +16,11 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Emacs; see the file COPYING.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+Boston, MA 02110-1301, USA.  */
 
 
-/* The following line tells the configuration script what sort of 
+/* The following line tells the configuration script what sort of
    operating system this machine is likely to run.
    USUAL-OPSYS="note"
 
@@ -29,7 +30,7 @@ For a Tektronix 16000 box (a 6130, perhaps?), use `-opsystem=bsd4-2'.
 Use `-machine=ns16000' for both.
 NOTE-END  */
 
-/* Define WORDS_BIG_ENDIAN iff lowest-numbered byte in a word
+/* Define WORDS_BIG_ENDIAN if lowest-numbered byte in a word
    is the most significant byte.  */
 
 #undef WORDS_BIG_ENDIAN
@@ -85,16 +86,10 @@ NOTE-END  */
 #undef BSTRING
 #define BSTRING
 
-/* Macro definitions to emulate BSD functions with SysV ones */
-#undef bcopy
-#undef bzero
-#undef bcmp
-
-#define bcopy(a,b,s)	memcpy(b,a,s)
-#define bzero(a,s)	memset(a,0,s)
-#define bcmp		memcmp
-
 /* This avoids problems with uninitialized static variables going in .data.  */
 #define static
 
 #endif /* USG */
+
+/* arch-tag: 4210db3c-e35c-4b96-9399-1dbde3e00a57
+   (do not change this comment) */
