@@ -1,16 +1,5 @@
 #include "sunos4-0.h"
 
-/* 4.1.1 makes these system calls interruptible.  */
-
-#define read sys_read
-#define write sys_write
-#define open sys_open
-#define close sys_close
-
-#define INTERRUPTIBLE_OPEN
-#define INTERRUPTIBLE_CLOSE
-#define INTERRUPTIBLE_IO
-
 /* Cause the compilation of oldxmenu to use the right -I option.  */
 #define OLDXMENU_OPTIONS CFLAGS=C_SWITCH_SYSTEM
 
@@ -42,3 +31,6 @@
 
 /* Define dlopen, dlclose, dlsym.  */
 #define USE_DL_STUBS
+
+/* arch-tag: 154e2eb2-2180-4d66-90b9-7e56a22004f2
+   (do not change this comment) */
