@@ -1,12 +1,12 @@
 /* Input event support for Emacs on the Microsoft W32 API.
    Copyright (C) 1992, 1993, 1995, 2001, 2002, 2003, 2004,
-                 2005, 2006, 2007  Free Software Foundation, Inc.
+                 2005, 2006, 2007, 2008  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
 GNU Emacs is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
+the Free Software Foundation; either version 3, or (at your option)
 any later version.
 
 GNU Emacs is distributed in the hope that it will be useful,
@@ -39,6 +39,7 @@ Boston, MA 02110-1301, USA.
 #include "lisp.h"
 #include "keyboard.h"
 #include "frame.h"
+#include "dispextern.h"
 #include "blockinput.h"
 #include "termhooks.h"
 #include "w32heap.h"
@@ -54,9 +55,6 @@ static DWORD movement_time;
 /* from keyboard.c */
 extern void reinvoke_input_signal (void);
 
-/* from dispnew.c */
-extern int change_frame_size (FRAME_PTR, int, int, int, int);
-
 /* from w32console.c */
 extern int w32_use_full_screen_buffer;
 
@@ -622,7 +620,7 @@ resize_event (WINDOW_BUFFER_SIZE_RECORD *event)
 {
   FRAME_PTR f = get_frame ();
 
-  change_frame_size (f, event->dwSize.Y, event->dwSize.X, 0, 1);
+  change_frame_size (f, event->dwSize.Y, event->dwSize.X, 0, 1, 0);
   SET_FRAME_GARBAGED (f);
 }
 
@@ -639,7 +637,7 @@ maybe_generate_resize_event ()
   change_frame_size (f,
 		     1 + info.srWindow.Bottom - info.srWindow.Top,
 		     1 + info.srWindow.Right - info.srWindow.Left,
-		     0, 0);
+		     0, 0, 0);
 }
 
 int
